@@ -141,7 +141,12 @@ def sqlite_s3_query(url, get_credentials=lambda now: (
         with make_auth_request(http_client, 'HEAD', (), ()) as response:
             head_headers = response.headers
             next(response.iter_bytes())
-        version_id = head_headers['x-amz-version-id']
+
+        try:
+            version_id = head_headers['x-amz-version-id']
+        except Exception:
+            raise Exception('The bucket must have versioning enabled')
+
         size = int(head_headers['content-length'])
 
         def make_struct(fields):
